from setuptools import setup

setup(
    name="pyrs-py",
    version="0.1.1",
    description="",
    long_description="",
    url="https://www.github.com/ra0x3/pyrs",
    author="ra0x3",
    author_email="ra0x3@gmail.com",
    packages=[],
    classifiers=["Development Status :: 1 - Planning"],
)
